nengolib\.networks\.RollingWindow
=================================

.. currentmodule:: nengolib.networks

.. autoclass:: nengolib.networks.RollingWindow

   .. automethod:: nengolib.networks.RollingWindow.add_output
